/**
 * Copyright (C) 2009  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.deployment;


/**
 *
 * Counts the number of processes already deployed.
 *
 * This class should have only one instance stored in database.
 *
 * Used to have unique process ids with the scheme: {processNamespace}processName$number where number is a simple number,
 * Each process has a unique number.
 *
 * @author Guillaume Porcher
 *
 */
public class ProcessDeploymentCounter {

  // Use a fixed DBID to make sure this is unique in database
  protected long dbid = 42;
  // DB version (to check for concurrent updates)
  protected long dbversion;
  // Counter of process deployed
  protected long processCounter = 1;

  public long getAndIncrementProcessCounter() {
    return this.processCounter++;
  }
}
