/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import java.util.HashSet;
import java.util.Set;

import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.exception.InstanceNotFoundException;
import org.ow2.orchestra.facade.exception.OrchestraWrapperException;
import org.ow2.orchestra.facade.runtime.ActivityInstance;
import org.ow2.orchestra.facade.runtime.ActivityState;
import org.ow2.orchestra.facade.runtime.full.ActivityFullInstance;
import org.ow2.orchestra.facade.uuid.ProcessInstanceUUID;
import org.ow2.orchestra.services.Querier;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.util.EnvTool;

public final class FindActivityInstancesCommand implements Command<Set<ActivityInstance>> {

  private static final long serialVersionUID = 7511362213907431496L;

  private final ProcessInstanceUUID processUUID;
  private final ActivityState activityState;

  /**
   * @param processUUID
   * @param activityState
   */
  public FindActivityInstancesCommand(final ProcessInstanceUUID processUUID, final ActivityState activityState) {
    this.processUUID = processUUID;
    this.activityState = activityState;
  }
  public FindActivityInstancesCommand(final ProcessInstanceUUID processUUID) {
    this.processUUID = processUUID;
    this.activityState = null;
  }
  public Set<ActivityInstance> execute(final Environment environment) {
    final Set<ActivityInstance> result = new HashSet<ActivityInstance>();
    final Querier querier = EnvTool.getQuerier();
    if (querier.getProcessInstance(this.processUUID) == null) {
      throw new OrchestraWrapperException(new InstanceNotFoundException(this.processUUID));
    }
    Set<ActivityFullInstance> activityFullInstances;
    if (this.processUUID != null && this.activityState != null) {
      activityFullInstances = querier.findActivityInstances(this.processUUID, this.activityState);
    } else {
      activityFullInstances = querier.findActivityInstances(this.processUUID);
    }
    for (final ActivityFullInstance activityFullInstance : activityFullInstances) {
      result.add(activityFullInstance.copy());
    }
    return result;
  }
}
