/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.exception.OrchestraRuntimeException;
import org.ow2.orchestra.facade.exception.OrchestraWrapperException;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.services.Querier;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.util.EnvTool;

public final class RemoveProcessCommand implements Command<Boolean> {

  private static final long serialVersionUID = -1626991011601734973L;

  private final ProcessDefinitionUUID pduuid;
  /**
   * @param pduuid
   */
  public RemoveProcessCommand(final ProcessDefinitionUUID pduuid) {
    this.pduuid = pduuid;
  }

  public Boolean execute(final Environment environment) {
    if (this.pduuid == null) {
      throw new IllegalArgumentException("Process definition uuid is null");
    }
    final Querier querier = EnvTool.getQuerier();
    if (EnvTool.getRepository().getProcess(this.pduuid) != null) {
      throw new OrchestraWrapperException(new OrchestraRuntimeException(
          "Process " + this.pduuid + " is still deployed. Please undeploy it first."));
    }
    if (!querier.findProcessInstances(this.pduuid).isEmpty()) {
      throw new OrchestraWrapperException(new OrchestraRuntimeException(
          "Some instances of process " + this.pduuid + " are not removed. Please remove instances first."));
    }
    return Boolean.valueOf(querier.removeProcessDefinition(this.pduuid) != null);
  }
}
