/**
 * Copyright (C) 2006-2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.parsing.binding;

import org.ow2.orchestra.definition.Node;
import org.ow2.orchestra.definition.activity.Throw;
import org.ow2.orchestra.facade.def.full.BpelActivityFullDefinition;
import org.ow2.orchestra.facade.def.full.ThrowActivityFullDefinition;
import org.ow2.orchestra.facade.def.full.impl.ThrowActivityFullDefinitionImpl;
import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.util.XmlUtil;
import org.ow2.orchestra.xml.Parse;
import org.ow2.orchestra.xml.Parser;
import org.w3c.dom.Element;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author S. Ali Tokmen
 */
public class ThrowBinding extends ActivityBinding {

  /**
   * log.
   */
  private static Logger log = Logger.getLogger(ThrowBinding.class.getName());

  public ThrowBinding() {
    super("throw", ActivityType.THROW);
  }

  /**
   * Parses the given dom element to build a Node and a behaviour.
   *
   * @param element dom element to parse
   * @param parse   parse
   * @param parser  parser
   * @return the build behaviour!
   */
  public Object parse(final Element element, final Parse parse, final Parser parser) {
    if (ThrowBinding.log.isLoggable(Level.FINE)) {
      ThrowBinding.log.fine("parsing element = " + element);
    }

    final Throw throwActivity = new Throw();
    this.setEnclosingScope(throwActivity, parse);
    this.parseStandardAttributes(element, throwActivity, parse);
    ActivityBinding.parseExtensionAttributes(element, throwActivity, parse);
    this.parseStandardElements(element, throwActivity, parse);
    ActivityBinding.parseExtensionElements(element, throwActivity, parse);

    // attributes
    throwActivity.setFaultName(XmlUtil.attributeQName(element, "faultName"));
    throwActivity.setFaultVariable(XmlUtil.attribute(element, "faultVariable"));

    final DefinitionKeeper definitionKeeper = parse.findObject(DefinitionKeeper.class);
    final ThrowActivityFullDefinition activityFullDefinition = (ThrowActivityFullDefinition) definitionKeeper
            .getActivityFullDefinition();

    activityFullDefinition.setFaultName(throwActivity.getFaultName());
    activityFullDefinition.setFaultVariable(throwActivity.getFaultVariable());

    final Node activityNode = this.createActivityNode(parse, parser, throwActivity);
    return activityNode;
  }

  @Override
  public BpelActivityFullDefinition createActivityFullDefinition(final ProcessDefinitionUUID processDefinitionUUID,
                                                                 final ActivityDefinitionUUID activityDefinitionUUID, final String name, final Parse parse) {
    return new ThrowActivityFullDefinitionImpl(processDefinitionUUID, activityDefinitionUUID, name);
  }

}
