/**
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.parsing.binding.extension;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;


/**
 * @author manhtoan
 */
public class ExtensionsInfo implements Serializable {
  private static final long serialVersionUID = 2L;
  protected List<Extension> extensionsInfos = new ArrayList<Extension>();

  public ExtensionsInfo() {
  }

  public void setListDefinition(List<Extension> listDefinition) {
    this.extensionsInfos = listDefinition;
  }

  public List<Extension> getListDefinition() {
    return extensionsInfos;
  }

  public void addDefinition(Extension extDefinition) {
    boolean exist = false;
    for (Extension e : extensionsInfos) {
      if (e.getNamespace().equals(extDefinition)) {
        exist = true;
        if (!e.isMustUnderstand()) e.setMustUnderstand(extDefinition.isMustUnderstand());
      }
    }
    if (!exist) extensionsInfos.add(extDefinition);
  }

  /* return true if ns is an extension namespace*/
  public boolean isExtensionNamespace(String ns) {
    for (Extension extDef : extensionsInfos) {
      if (extDef.getNamespace().equals(ns)) return true;
    }
    return false;
  }

  /* return the extension definition if ns is an extension namespace and return null in the other case*/
  public Extension getExtensionDefinitionByNamespace(String ns) {
    for (Extension extDef : extensionsInfos) {
      if (extDef.getNamespace().equals(ns)) return extDef;
    }
    return null;
  }
}
