/*******************************************************************************
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.rest;

import org.ow2.orchestra.env.EnvironmentFactory;
import org.ow2.orchestra.facade.InstanceManagementAPI;
import org.ow2.orchestra.facade.data.runtime.JobData;
import org.ow2.orchestra.facade.data.runtime.PendingMessageData;
import org.ow2.orchestra.facade.exception.InstanceNotFoundException;
import org.ow2.orchestra.facade.exception.JobNotFoundException;
import org.ow2.orchestra.facade.rest.CollectionWrapper;
import org.ow2.orchestra.facade.rest.JaxRSInstanceManagementAPI;
import org.ow2.orchestra.facade.uuid.ProcessInstanceUUID;
import org.ow2.orchestra.jmx.ClassLoaderInterceptor;
import org.ow2.orchestra.jmx.InstanceManagementAPIImpl;

import java.lang.reflect.Proxy;

/**
 * @author Guillaume Porcher
 */
public class JaxRSInstanceManagementAPIImpl implements JaxRSInstanceManagementAPI {
  private final InstanceManagementAPI internalAPI;

  public JaxRSInstanceManagementAPIImpl(EnvironmentFactory environmentFactory) {
    final InstanceManagementAPI realApi = new InstanceManagementAPIImpl(environmentFactory);
    final ClassLoaderInterceptor clInterceptor = new ClassLoaderInterceptor(realApi);
    this.internalAPI = (InstanceManagementAPI) Proxy.newProxyInstance(
            JaxRSInstanceManagementAPIImpl.class.getClassLoader(),
            new Class[]{InstanceManagementAPI.class},
            clInterceptor);
  }


  public void exit(ProcessInstanceUUID processInstanceUUID) throws InstanceNotFoundException {
    this.internalAPI.exit(processInstanceUUID);
  }

  public void resume(ProcessInstanceUUID processInstanceUUID) throws InstanceNotFoundException {
    this.internalAPI.resume(processInstanceUUID);
  }


  public void suspend(ProcessInstanceUUID processInstanceUUID) throws InstanceNotFoundException {
    this.internalAPI.suspend(processInstanceUUID);
  }

  public boolean remove(ProcessInstanceUUID processInstanceUUID) {
    return this.internalAPI.remove(processInstanceUUID);
  }

  public CollectionWrapper<JobData> findJobsWithException() {
    return CollectionWrapper.make(this.internalAPI.findJobsWithException());
  }

  public void retryJob(JobData job, int retries) throws JobNotFoundException {
    this.internalAPI.retryJob(job, retries);
  }

  public CollectionWrapper<PendingMessageData> getPendingMessages() {
    return CollectionWrapper.make(this.internalAPI.getPendingMessages());
  }

  public void removePendingMessage(PendingMessageData message) {
    this.internalAPI.removePendingMessage(message);
  }
}
