/*******************************************************************************
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.rest;

import org.ow2.orchestra.env.EnvironmentFactory;
import org.ow2.orchestra.facade.Deployment;
import org.ow2.orchestra.facade.ManagementAPI;
import org.ow2.orchestra.facade.def.ProcessDefinition;
import org.ow2.orchestra.facade.exception.ProcessNotFoundException;
import org.ow2.orchestra.facade.rest.ByteArrayWrapper;
import org.ow2.orchestra.facade.rest.InterfaceWrapper;
import org.ow2.orchestra.facade.rest.JaxRSManagementAPI;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.jmx.ClassLoaderInterceptor;
import org.ow2.orchestra.jmx.ManagementAPIImpl;

import javax.xml.namespace.QName;
import java.lang.reflect.Proxy;

/**
 * @author Guillaume Porcher
 */
public class JaxRSManagementAPIImpl implements JaxRSManagementAPI {

  private final ManagementAPI managementAPI;

  public JaxRSManagementAPIImpl(EnvironmentFactory environmentFactory) {
    final ManagementAPI realApi = new ManagementAPIImpl(environmentFactory);
    final ClassLoaderInterceptor clInterceptor = new ClassLoaderInterceptor(realApi);
    this.managementAPI = (ManagementAPI) Proxy.newProxyInstance(
            JaxRSManagementAPIImpl.class.getClassLoader(),
            new Class[]{ManagementAPI.class},
            clInterceptor);
  }


  public InterfaceWrapper<ProcessDefinition> deploy(final Deployment bpelDeployment) {
    return InterfaceWrapper.make(this.managementAPI.deploy(bpelDeployment));
  }

  public void deployWebServices(final ProcessDefinitionUUID processDefinitionUUID) {
    this.managementAPI.deployWebServices(processDefinitionUUID);
  }

  public void undeployWebServices(final ProcessDefinitionUUID processDefinitionUUID) {
    this.managementAPI.undeployWebServices(processDefinitionUUID);
  }

  public boolean undeploy(final String processNamespace,
                          final String processName) {
    return this.managementAPI.undeploy(new QName(processNamespace, processName));
  }

  public boolean undeploy(final ProcessDefinitionUUID pduuid) {
    return this.managementAPI.undeploy(pduuid);
  }


  public boolean remove(final ProcessDefinitionUUID processDefinitionUUID) {
    return this.managementAPI.remove(processDefinitionUUID);
  }

  public boolean activate(final ProcessDefinitionUUID processDefinitionUUID) throws ProcessNotFoundException {
    return this.managementAPI.activate(processDefinitionUUID);
  }

  public boolean retire(final ProcessDefinitionUUID processDefinitionUUID) throws ProcessNotFoundException {
    return this.managementAPI.retire(processDefinitionUUID);
  }

  public void refreshProcess(final ProcessDefinitionUUID processDefinitionUUID) {
    this.managementAPI.refreshProcess(processDefinitionUUID);
  }

  public InterfaceWrapper<ProcessDefinition> deployBar(final ByteArrayWrapper barFile) {
    return InterfaceWrapper.make(this.managementAPI.deployBar(barFile.getContent()));
  }

  public void initialize() {
    this.managementAPI.initialize();
  }

}
