/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.runtime;


public class ForEachRuntime {

  public static final int NO_MORE_COUNTER_VALUE = -1;

  protected long dbid;
  protected int dbversion;

  protected int finalCounterValue;
  // Completion condition B
  // decremented for each terminated branches (successful only if onlySuccessful==true)
  protected int remainingBranchesBeforeCompletion;

  protected int nextCounterValue;

  protected ForEachRuntime() {
  }

  public ForEachRuntime(final int startCounterValue,
      final int finalCounterValue, final int completionValue) {
    this.finalCounterValue = finalCounterValue;
    this.nextCounterValue = startCounterValue;
    this.remainingBranchesBeforeCompletion = completionValue;
  }

  public boolean isCompleted() {
    if (this.remainingBranchesBeforeCompletion > 0) {
      return false;
    }
    return true;
  }

  public void addTerminatedBranch(final boolean successful, final boolean onlySuccessful) {
    if (!onlySuccessful || successful) {
      this.remainingBranchesBeforeCompletion--;
    }
  }

  /**
   * @return the next counter value or {@link ForEachRuntime.NO_MORE_COUNTER_VALUE} if no more executions are intended
   */
  public int getNextCurrentCounterValue() {
    int result = this.nextCounterValue;
    if (result > this.finalCounterValue) {
      result = ForEachRuntime.NO_MORE_COUNTER_VALUE;
    } else {
      this.nextCounterValue++;
    }
    return result;
  }


  public int getFinalCounterValue() {
    return this.finalCounterValue;
  }

  @Override
  public String toString() {
    return ForEachRuntime.class.getName()
      + "[finalCounterValue: " + this.finalCounterValue
      + ", nextCounterValue: " + this.nextCounterValue
      + "]";
  }
}
