/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.services.jobexecutor;

import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.services.job.JobImpl;
import org.ow2.orchestra.util.Misc;

/**
 * @author Tom Baeyens
 */
public class GetNextDueDateCmd implements Command<Date> {

  private static final long serialVersionUID = 1L;
  private static final Logger LOG = Logger.getLogger(GetNextDueDateCmd.class.getName());

  public GetNextDueDateCmd() {
  }

  public Date execute(final Environment environment) {
    Date nextDueDate = null;
    Misc.fastDynamicLog(GetNextDueDateCmd.LOG, Level.FINE, "getting next due date...");
    final JobDbSession jobDbSession = environment.get(JobDbSession.class);
    final JobImpl< ? > job = jobDbSession.findFirstDueJob();
    if (job != null) {
      nextDueDate = job.getDueDate();
    }
    Misc.fastDynamicLog(GetNextDueDateCmd.LOG, Level.FINE, "next due date is %s", nextDueDate);
    return nextDueDate;
  }

}
